@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2015-2018 VMware, Inc. All Rights Reserved.
+ * Copyright (C) 2015-2020 VMware, Inc. All Rights Reserved.
  *
  * Licensed under the GNU Lesser General Public License v2.1 (the "License");
  * you may not use this file except in compliance with the License. The terms
@@ -93,8 +93,7 @@ TDNFPkgsToExclude(
     pSetOpt = pTdnf->pArgs->pSetOpt;
     while(pSetOpt)
     {
-        if(pSetOpt->nType == CMDOPT_KEYVALUE &&
-           !strcasecmp(pSetOpt->pszOptName, "exclude"))
+        if(!strcasecmp(pSetOpt->pszOptName, "exclude"))
         {
             dwCount++;
         }
@@ -125,8 +124,7 @@ TDNFPkgsToExclude(
         pSetOpt = pTdnf->pArgs->pSetOpt;
         while(pSetOpt)
         {
-            if(pSetOpt->nType == CMDOPT_KEYVALUE &&
-               !strcasecmp(pSetOpt->pszOptName, "exclude"))
+            if(!strcasecmp(pSetOpt->pszOptName, "exclude"))
             {
                 dwError = TDNFAllocateString(
                       pSetOpt->pszOptValue,
