@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2015-2021 VMware, Inc. All Rights Reserved.
+ * Copyright (C) 2015-2022 VMware, Inc. All Rights Reserved.
  *
  * Licensed under the GNU Lesser General Public License v2.1 (the "License");
  * you may not use this file except in compliance with the License. The terms
@@ -540,7 +540,6 @@ TDNFGetGlobPackages(
     )
 {
     uint32_t dwError = 0;
-    int dwPkgIndex = 0;
     PSolvPackageList pSolvPkgList = NULL;
 
     if(!pSack || IsNullOrEmptyString(pszPkgGlob) || !pQueueGoal)
@@ -557,7 +556,7 @@ TDNFGetGlobPackages(
 
     if(pSolvPkgList->queuePackages.count > 0)
     {
-        for(dwPkgIndex = 0;
+        for(int dwPkgIndex = 0;
             dwPkgIndex < pSolvPkgList->queuePackages.count;
             dwPkgIndex++)
         {
@@ -934,85 +933,6 @@ error:
     return dwError;
 }
 
-uint32_t
-TDNFHasMinVersionInList(
-    PTDNF pTdnf,
-    PTDNF_PKG_INFO pPkgInfos
-    )
-{
-    uint32_t dwError = 0;
-    PTDNF_PKG_INFO pPkgInfo;
-    char **ppszMinVersions = NULL;
-    char **ppszTokens = NULL;
-    char *pszTemp = NULL;
-    int i;
-
-    if(!pTdnf || !pPkgInfos)
-    {
-        dwError = ERROR_TDNF_INVALID_PARAMETER;
-        BAIL_ON_TDNF_ERROR(dwError);
-    }
-
-    ppszMinVersions = pTdnf->pConf->ppszMinVersions;
-
-    for (i = 0; ppszMinVersions[i]; i++)
-    {
-        dwError = TDNFAllocateString(ppszMinVersions[i], &pszTemp);
-        BAIL_ON_TDNF_ERROR(dwError);
-
-        dwError = TDNFSplitStringToArray(pszTemp, "=", &ppszTokens);
-        BAIL_ON_TDNF_ERROR(dwError);
-
-        if (ppszTokens[0] && ppszTokens[1])
-        {
-            for(pPkgInfo = pPkgInfos; pPkgInfo; pPkgInfo = pPkgInfo->pNext)
-            {
-                if (strcmp(ppszTokens[0], pPkgInfo->pszName) == 0)
-                {
-                    if (rpmvercmp(ppszTokens[1], pPkgInfo->pszEVR) > 0)
-                    {
-                        dwError = ERROR_TDNF_DOWNGRADE_NOT_ALLOWED;
-                        BAIL_ON_TDNF_ERROR(dwError);
-                    }
-                }
-            }
-        }
-        TDNF_SAFE_FREE_MEMORY(pszTemp);
-        TDNF_SAFE_FREE_STRINGARRAY(ppszTokens);
-    }
-cleanup:
-    TDNF_SAFE_FREE_MEMORY(pszTemp);
-    TDNF_SAFE_FREE_STRINGARRAY(ppszTokens);
-    return dwError;
-error:
-    goto cleanup;
-}
-
-uint32_t
-TDNFCheckMinVersions(
-    PTDNF pTdnf,
-    PTDNF_SOLVED_PKG_INFO pSolvedPkgInfo
-    )
-{
-    uint32_t dwError = 0;
-
-    if(!pTdnf || !pSolvedPkgInfo)
-    {
-        dwError = ERROR_TDNF_INVALID_PARAMETER;
-        BAIL_ON_TDNF_ERROR(dwError);
-    }
-
-    if(pSolvedPkgInfo->pPkgsToDowngrade &&
-       pTdnf->pConf && pTdnf->pConf->ppszMinVersions)
-    {
-        dwError = TDNFHasMinVersionInList(pTdnf, pSolvedPkgInfo->pPkgsToDowngrade);
-        BAIL_ON_TDNF_ERROR(dwError);
-    }
-
-error:
-    return dwError;
-}
-
 uint32_t
 TDNFPopulatePkgInfos(
     PSolvSack pSack,
