@@ -30,24 +30,24 @@ def remove_dummy_pretrans_dependency(utils):
 def test_install_pretrans_lessthan_fail(utils):
     remove_dummy_pretrans_dependency(utils)
     ret = utils.run(['tdnf', 'install', '-y', 'tdnf-test-pretrans-one'])
-    assert(ret['stderr'][0].startswith('Detected rpm pre-transaction dependency'))
-    assert(ret['retval'] == 1515)
+    assert ret['stderr'][0].startswith('Detected rpm pre-transaction dependency')
+    assert ret['retval'] == 1515
 
 
 def test_install_pretrans_greaterthan_fail(utils):
     remove_dummy_pretrans_dependency(utils)
     ret = utils.run(['tdnf', 'install', '-y', 'tdnf-test-pretrans-two'])
-    assert(ret['stderr'][0].startswith('Detected rpm pre-transaction dependency'))
-    assert(ret['retval'] == 1515)
+    assert ret['stderr'][0].startswith('Detected rpm pre-transaction dependency')
+    assert ret['retval'] == 1515
 
 
 def test_install_pretrans_lessthan_success(utils):
     install_dummy_pretrans_dependency(utils)
     ret = utils.run(['tdnf', 'install', '-y', 'tdnf-test-pretrans-one'])
-    assert(ret['retval'] == 0)
+    assert ret['retval'] == 0
 
 
 def test_install_pretrans_greaterthan_success(utils):
     install_dummy_pretrans_dependency(utils)
     ret = utils.run(['tdnf', 'install', '-y', 'tdnf-test-pretrans-two'])
-    assert(ret['retval'] == 0)
+    assert ret['retval'] == 0
