@@ -21,30 +21,30 @@ def teardown_test(utils):
 
 def test_repolist(utils):
     ret = utils.run(['tdnf', 'repolist'])
-    assert(ret['retval'] == 0)
+    assert ret['retval'] == 0
 
 
 def test_repolist_all(utils):
     ret = utils.run(['tdnf', 'repolist', 'all'])
-    assert(ret['retval'] == 0)
+    assert ret['retval'] == 0
 
 
 def test_repolist_enabled(utils):
     ret = utils.run(['tdnf', 'repolist', 'enabled'])
-    assert(ret['retval'] == 0)
+    assert ret['retval'] == 0
 
 
 def test_repolist_disabled(utils):
     ret = utils.run(['tdnf', 'repolist', 'disabled'])
-    assert(ret['retval'] == 0)
+    assert ret['retval'] == 0
 
 
 def test_repolist_invalid(utils):
     ret = utils.run(['tdnf', 'repolist', 'invalid_repo'])
-    assert(ret['retval'] == 901)
+    assert ret['retval'] == 901
 
 
 # memcheck
 def test_repolist_memcheck(utils):
     ret = utils.run_memcheck(['tdnf', 'repolist'])
-    assert(ret['retval'] == 0)
+    assert ret['retval'] == 0
