@@ -28,10 +28,10 @@ def test_whatdepends(utils):
                      'repoquery',
                      '--whatdepends',
                      BASE_PKG])
-    assert(ret['retval'] == 0)
+    assert ret['retval'] == 0
 
     for d in ['enhances', 'recommends', 'requires', 'suggests', 'supplements']:
-        assert('tdnf-repoquery-{}'.format(d) in '\n'.join(ret['stdout']))
+        assert 'tdnf-repoquery-{}'.format(d) in '\n'.join(ret['stdout'])
 
 
 # repoquery should list the package that has a specific
@@ -46,8 +46,8 @@ def test_what_alldeps(utils):
                          '--what{}'.format(dep),
                          BASE_PKG
                          ])
-        assert(ret['retval'] == 0)
-        assert('tdnf-repoquery-{}'.format(dep) in '\n'.join(ret['stdout']))
+        assert ret['retval'] == 0
+        assert 'tdnf-repoquery-{}'.format(dep) in '\n'.join(ret['stdout'])
 
 
 # repoquery should list the package that requires BASE_PKG
@@ -60,8 +60,8 @@ def test_what_2(utils):
                      '--whatrequires',
                      "{},{}".format('doesnotexist', BASE_PKG)
                      ])
-    assert(ret['retval'] == 0)
-    assert('tdnf-repoquery-requires' in '\n'.join(ret['stdout']))
+    assert ret['retval'] == 0
+    assert 'tdnf-repoquery-requires' in '\n'.join(ret['stdout'])
 
 
 # packages should have specified relation to BASE_PKG
@@ -75,8 +75,8 @@ def test_alldeps(utils):
                          '--{}'.format(dep),
                          'tdnf-repoquery-{}'.format(dep)
                          ])
-        assert(ret['retval'] == 0)
-        assert(BASE_PKG in '\n'.join(ret['stdout']))
+        assert ret['retval'] == 0
+        assert BASE_PKG in '\n'.join(ret['stdout'])
 
 
 # all these packages depend on BASE_PKG
@@ -86,8 +86,8 @@ def test_depends(utils):
                          'repoquery',
                          '--depends',
                          'tdnf-repoquery-{}'.format(dep)])
-        assert(ret['retval'] == 0)
-        assert(BASE_PKG in '\n'.join(ret['stdout']))
+        assert ret['retval'] == 0
+        assert BASE_PKG in '\n'.join(ret['stdout'])
 
 
 # each package has a file with its name
@@ -101,8 +101,8 @@ def test_list(utils):
                          '--list',
                          'tdnf-repoquery-{}'.format(dep)
                          ])
-        assert(ret['retval'] == 0)
-        assert('/usr/lib/repoquery/tdnf-repoquery-{}'.format(dep) in '\n'.join(ret['stdout']))
+        assert ret['retval'] == 0
+        assert '/usr/lib/repoquery/tdnf-repoquery-{}'.format(dep) in '\n'.join(ret['stdout'])
 
 
 # like test_list(), but the other way around
@@ -116,39 +116,39 @@ def test_file(utils):
                          '--file',
                          '/usr/lib/repoquery/tdnf-repoquery-{}'.format(dep)
                          ])
-        assert(ret['retval'] == 0)
-        assert('tdnf-repoquery-{}'.format(dep) in '\n'.join(ret['stdout']))
+        assert ret['retval'] == 0
+        assert 'tdnf-repoquery-{}'.format(dep) in '\n'.join(ret['stdout'])
 
 
 def test_available(utils):
     ret = utils.run(['tdnf',
                      'repoquery',
                      '--available'])
-    assert(ret['retval'] == 0)
-    assert(BASE_PKG in '\n'.join(ret['stdout']))
+    assert ret['retval'] == 0
+    assert BASE_PKG in '\n'.join(ret['stdout'])
 
 
 def test_installed(utils):
     ret = utils.run(['tdnf',
                      'install', '-y', '--nogpgcheck',
                      BASE_PKG])
-    assert(ret['retval'] == 0)
+    assert ret['retval'] == 0
 
     ret = utils.run(['tdnf',
                      'repoquery',
                      '--installed'])
-    assert(ret['retval'] == 0)
-    assert(BASE_PKG in '\n'.join(ret['stdout']))
+    assert ret['retval'] == 0
+    assert BASE_PKG in '\n'.join(ret['stdout'])
 
 
 def test_extras(utils):
     ret = utils.run(['tdnf',
                      'repoquery',
                      '--extras'])
-    assert(ret['retval'] == 0)
+    assert ret['retval'] == 0
     # we are using just the 'photon-test repo,
     # so any real system package is 'extra'
-    assert('glibc' in '\n'.join(ret['stdout']))
+    assert 'glibc' in '\n'.join(ret['stdout'])
 
 
 def test_upgrades(utils):
@@ -158,13 +158,13 @@ def test_upgrades(utils):
     ret = utils.run(['tdnf',
                      'install', '-y', '--nogpgcheck',
                      pkg_low])
-    assert(ret['retval'] == 0)
+    assert ret['retval'] == 0
 
     ret = utils.run(['tdnf',
                      'repoquery',
                      '--upgrades'])
-    assert(ret['retval'] == 0)
-    assert(pkg_high in '\n'.join(ret['stdout']))
+    assert ret['retval'] == 0
+    assert pkg_high in '\n'.join(ret['stdout'])
 
 
 def test_changelog(utils):
@@ -172,13 +172,13 @@ def test_changelog(utils):
                      'repoquery',
                      '--changelogs',
                      'tdnf-repoquery-changelog'])
-    assert(ret['retval'] == 0)
+    assert ret['retval'] == 0
 
     # tests changelog text, author and date
     output = '\n'.join(ret['stdout'])
-    assert("needle in a haystack" in output)
-    assert("John Doe" in output)
-    assert("Wed Jan 01 2020" in output)
+    assert "needle in a haystack" in output
+    assert "John Doe" in output
+    assert "Wed Jan 01 2020" in output
 
 
 def test_source(utils):
@@ -190,11 +190,11 @@ def test_source(utils):
                      'repoquery',
                      '--source',
                      pkgname])
-    assert(ret['retval'] == 0)
+    assert ret['retval'] == 0
     output = '\n'.join(ret['stdout'])
-    assert(pkgname in output)
-    assert('src' in output)
-    assert('x86_64' not in output)
+    assert pkgname in output
+    assert 'src' in output
+    assert 'x86_64' not in output
 
 
 # each package has a file with its name
@@ -205,4 +205,4 @@ def test_list1(utils):
                               '--list',
                               'tdnf-repoquery-{}'.format(dep)
                               ])
-    assert(ret['retval'] == 0)
+    assert ret['retval'] == 0
